# anchor: body: v1

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144010.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144010.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144014.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144014.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144017.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144017.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144021.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144021.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144024.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144024.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144031.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251204_144031.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175953.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175953.jpg?raw=true) |  |  |
